/****************************************************************************
** Meta object code from reading C++ file 'kmahjongg.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.12.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../kmahjongg-26.07.90/src/kmahjongg.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmahjongg.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.12.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN9KMahjonggE_t {};
} // unnamed namespace

template <> constexpr inline auto KMahjongg::qt_create_metaobjectdata<qt_meta_tag_ZN9KMahjonggE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "KMahjongg",
        "startNewGame",
        "",
        "loadSettings",
        "showStatusText",
        "msg",
        "board",
        "showItemNumber",
        "maximum",
        "current",
        "left",
        "gameOver",
        "numRemoved",
        "cheats",
        "demoOrMoveListAnimationOver",
        "demoGameLost",
        "showSettings",
        "startNewNumeric",
        "saveGame",
        "loadGame",
        "restartGame",
        "undo",
        "redo",
        "pause",
        "demoMode",
        "displayTime",
        "timestring",
        "showHighscores",
        "slotBoardEditor",
        "noMovesAvailable",
        "toggleFullscreen",
        "fullscreen"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'startNewGame'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'loadSettings'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'showStatusText'
        QtMocHelpers::SlotData<void(const QString &, long)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::QString, 5 }, { QMetaType::Long, 6 },
        }}),
        // Slot 'showItemNumber'
        QtMocHelpers::SlotData<void(int, int, int)>(7, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Int, 8 }, { QMetaType::Int, 9 }, { QMetaType::Int, 10 },
        }}),
        // Slot 'gameOver'
        QtMocHelpers::SlotData<void(unsigned short, unsigned short)>(11, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::UShort, 12 }, { QMetaType::UShort, 13 },
        }}),
        // Slot 'demoOrMoveListAnimationOver'
        QtMocHelpers::SlotData<void(bool)>(14, 2, QMC::AccessPublic, QMetaType::Void, {{
            { QMetaType::Bool, 15 },
        }}),
        // Slot 'showSettings'
        QtMocHelpers::SlotData<void()>(16, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'startNewNumeric'
        QtMocHelpers::SlotData<void()>(17, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'saveGame'
        QtMocHelpers::SlotData<void()>(18, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'loadGame'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'restartGame'
        QtMocHelpers::SlotData<void()>(20, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'undo'
        QtMocHelpers::SlotData<void()>(21, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'redo'
        QtMocHelpers::SlotData<void()>(22, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'pause'
        QtMocHelpers::SlotData<void()>(23, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'demoMode'
        QtMocHelpers::SlotData<void()>(24, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'displayTime'
        QtMocHelpers::SlotData<void(const QString &)>(25, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::QString, 26 },
        }}),
        // Slot 'showHighscores'
        QtMocHelpers::SlotData<void()>(27, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'slotBoardEditor'
        QtMocHelpers::SlotData<void()>(28, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'noMovesAvailable'
        QtMocHelpers::SlotData<void()>(29, 2, QMC::AccessPrivate, QMetaType::Void),
        // Slot 'toggleFullscreen'
        QtMocHelpers::SlotData<void(bool)>(30, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 31 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<KMahjongg, qt_meta_tag_ZN9KMahjonggE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject KMahjongg::staticMetaObject = { {
    QMetaObject::SuperData::link<KXmlGuiWindow::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KMahjonggE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KMahjonggE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN9KMahjonggE_t>.metaTypes,
    nullptr
} };

void KMahjongg::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<KMahjongg *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->startNewGame(); break;
        case 1: _t->loadSettings(); break;
        case 2: _t->showStatusText((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<long>>(_a[2]))); break;
        case 3: _t->showItemNumber((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[3]))); break;
        case 4: _t->gameOver((*reinterpret_cast<std::add_pointer_t<ushort>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<ushort>>(_a[2]))); break;
        case 5: _t->demoOrMoveListAnimationOver((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 6: _t->showSettings(); break;
        case 7: _t->startNewNumeric(); break;
        case 8: _t->saveGame(); break;
        case 9: _t->loadGame(); break;
        case 10: _t->restartGame(); break;
        case 11: _t->undo(); break;
        case 12: _t->redo(); break;
        case 13: _t->pause(); break;
        case 14: _t->demoMode(); break;
        case 15: _t->displayTime((*reinterpret_cast<std::add_pointer_t<QString>>(_a[1]))); break;
        case 16: _t->showHighscores(); break;
        case 17: _t->slotBoardEditor(); break;
        case 18: _t->noMovesAvailable(); break;
        case 19: _t->toggleFullscreen((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *KMahjongg::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMahjongg::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN9KMahjonggE_t>.strings))
        return static_cast<void*>(this);
    return KXmlGuiWindow::qt_metacast(_clname);
}

int KMahjongg::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KXmlGuiWindow::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 20)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 20;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 20)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 20;
    }
    return _id;
}
QT_WARNING_POP
