/********************************************************************************
** Form generated from reading UI file 'settings.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SETTINGS_H
#define UI_SETTINGS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_Settings
{
public:
    QVBoxLayout *vboxLayout;
    QCheckBox *kcfg_ShowMatchingTiles;
    QCheckBox *kcfg_SolvableGames;
    QCheckBox *kcfg_RemovedTiles;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *Settings)
    {
        if (Settings->objectName().isEmpty())
            Settings->setObjectName("Settings");
        Settings->resize(350, 251);
        vboxLayout = new QVBoxLayout(Settings);
        vboxLayout->setObjectName("vboxLayout");
        kcfg_ShowMatchingTiles = new QCheckBox(Settings);
        kcfg_ShowMatchingTiles->setObjectName("kcfg_ShowMatchingTiles");

        vboxLayout->addWidget(kcfg_ShowMatchingTiles);

        kcfg_SolvableGames = new QCheckBox(Settings);
        kcfg_SolvableGames->setObjectName("kcfg_SolvableGames");

        vboxLayout->addWidget(kcfg_SolvableGames);

        kcfg_RemovedTiles = new QCheckBox(Settings);
        kcfg_RemovedTiles->setObjectName("kcfg_RemovedTiles");

        vboxLayout->addWidget(kcfg_RemovedTiles);

        spacerItem = new QSpacerItem(161, 51, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(Settings);

        QMetaObject::connectSlotsByName(Settings);
    } // setupUi

    void retranslateUi(QWidget *Settings)
    {
        kcfg_ShowMatchingTiles->setText(tr2i18n("Blink matching tiles when first one is selected", nullptr));
        kcfg_SolvableGames->setText(tr2i18n("Generate solvable games", nullptr));
        kcfg_RemovedTiles->setText(tr2i18n("Show removed tiles", nullptr));
        (void)Settings;
    } // retranslateUi

};

namespace Ui {
    class Settings: public Ui_Settings {};
} // namespace Ui

QT_END_NAMESPACE

#endif // SETTINGS_H

