/********************************************************************************
** Form generated from reading UI file 'gametype.ui'
**
** Created by: Qt User Interface Compiler version 6.12.0
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_GAMETYPE_H
#define UI_GAMETYPE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFormLayout>
#include <QtWidgets/QGridLayout>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QListWidget>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>
#include <klocalizedstring.h>

QT_BEGIN_NAMESPACE

class Ui_KMahjonggLayoutSelector
{
public:
    QGridLayout *gridLayout_2;
    QVBoxLayout *verticalLayout_2;
    QCheckBox *kcfg_RandomLayout;
    QWidget *widgetNoRandom;
    QGridLayout *gridLayout;
    QVBoxLayout *layoutNoRandom;
    QHBoxLayout *_2;
    QVBoxLayout *_3;
    QListWidget *layoutList;
    QPushButton *getNewButton;
    QGroupBox *groupBox_2;
    QVBoxLayout *_4;
    QLabel *layoutPreview;
    QGroupBox *groupBox;
    QFormLayout *formLayout;
    QLabel *labelAuthor;
    QLabel *layoutAuthor;
    QLabel *labelContact;
    QLabel *layoutContact;
    QLabel *labelDescription;
    QLabel *layoutDescription;
    QLineEdit *kcfg_Layout;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *KMahjonggLayoutSelector)
    {
        if (KMahjonggLayoutSelector->objectName().isEmpty())
            KMahjonggLayoutSelector->setObjectName("KMahjonggLayoutSelector");
        KMahjonggLayoutSelector->resize(480, 461);
        KMahjonggLayoutSelector->setMaximumSize(QSize(800, 600));
        gridLayout_2 = new QGridLayout(KMahjonggLayoutSelector);
        gridLayout_2->setObjectName("gridLayout_2");
        verticalLayout_2 = new QVBoxLayout();
        verticalLayout_2->setObjectName("verticalLayout_2");
        kcfg_RandomLayout = new QCheckBox(KMahjonggLayoutSelector);
        kcfg_RandomLayout->setObjectName("kcfg_RandomLayout");

        verticalLayout_2->addWidget(kcfg_RandomLayout);

        widgetNoRandom = new QWidget(KMahjonggLayoutSelector);
        widgetNoRandom->setObjectName("widgetNoRandom");
        gridLayout = new QGridLayout(widgetNoRandom);
        gridLayout->setContentsMargins(0, 0, 0, 0);
        gridLayout->setObjectName("gridLayout");
        layoutNoRandom = new QVBoxLayout();
        layoutNoRandom->setObjectName("layoutNoRandom");
        _2 = new QHBoxLayout();
        _2->setObjectName("_2");
        _3 = new QVBoxLayout();
        _3->setObjectName("_3");
        layoutList = new QListWidget(widgetNoRandom);
        layoutList->setObjectName("layoutList");
        layoutList->setMinimumSize(QSize(120, 0));

        _3->addWidget(layoutList);

        getNewButton = new QPushButton(widgetNoRandom);
        getNewButton->setObjectName("getNewButton");

        _3->addWidget(getNewButton);


        _2->addLayout(_3);

        groupBox_2 = new QGroupBox(widgetNoRandom);
        groupBox_2->setObjectName("groupBox_2");
        _4 = new QVBoxLayout(groupBox_2);
        _4->setObjectName("_4");
        layoutPreview = new QLabel(groupBox_2);
        layoutPreview->setObjectName("layoutPreview");
        QSizePolicy sizePolicy(QSizePolicy::Policy::Fixed, QSizePolicy::Policy::Fixed);
        sizePolicy.setHorizontalStretch(0);
        sizePolicy.setVerticalStretch(0);
        sizePolicy.setHeightForWidth(layoutPreview->sizePolicy().hasHeightForWidth());
        layoutPreview->setSizePolicy(sizePolicy);
        layoutPreview->setMinimumSize(QSize(240, 180));

        _4->addWidget(layoutPreview);


        _2->addWidget(groupBox_2);


        layoutNoRandom->addLayout(_2);

        groupBox = new QGroupBox(widgetNoRandom);
        groupBox->setObjectName("groupBox");
        formLayout = new QFormLayout(groupBox);
        formLayout->setObjectName("formLayout");
        labelAuthor = new QLabel(groupBox);
        labelAuthor->setObjectName("labelAuthor");

        formLayout->setWidget(0, QFormLayout::ItemRole::LabelRole, labelAuthor);

        layoutAuthor = new QLabel(groupBox);
        layoutAuthor->setObjectName("layoutAuthor");

        formLayout->setWidget(0, QFormLayout::ItemRole::FieldRole, layoutAuthor);

        labelContact = new QLabel(groupBox);
        labelContact->setObjectName("labelContact");

        formLayout->setWidget(1, QFormLayout::ItemRole::LabelRole, labelContact);

        layoutContact = new QLabel(groupBox);
        layoutContact->setObjectName("layoutContact");

        formLayout->setWidget(1, QFormLayout::ItemRole::FieldRole, layoutContact);

        labelDescription = new QLabel(groupBox);
        labelDescription->setObjectName("labelDescription");

        formLayout->setWidget(2, QFormLayout::ItemRole::LabelRole, labelDescription);

        layoutDescription = new QLabel(groupBox);
        layoutDescription->setObjectName("layoutDescription");

        formLayout->setWidget(2, QFormLayout::ItemRole::FieldRole, layoutDescription);


        layoutNoRandom->addWidget(groupBox);

        kcfg_Layout = new QLineEdit(widgetNoRandom);
        kcfg_Layout->setObjectName("kcfg_Layout");
        kcfg_Layout->setEnabled(false);
        kcfg_Layout->setFrame(false);
        kcfg_Layout->setReadOnly(false);

        layoutNoRandom->addWidget(kcfg_Layout);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Policy::Minimum, QSizePolicy::Policy::Expanding);

        layoutNoRandom->addItem(spacerItem);


        gridLayout->addLayout(layoutNoRandom, 0, 0, 1, 1);


        verticalLayout_2->addWidget(widgetNoRandom);


        gridLayout_2->addLayout(verticalLayout_2, 0, 0, 1, 1);


        retranslateUi(KMahjonggLayoutSelector);
        QObject::connect(kcfg_RandomLayout, SIGNAL(toggled(bool)), KMahjonggLayoutSelector, SLOT(useRandomLayoutToggled(bool)));

        QMetaObject::connectSlotsByName(KMahjonggLayoutSelector);
    } // setupUi

    void retranslateUi(QWidget *KMahjonggLayoutSelector)
    {
        kcfg_RandomLayout->setText(tr2i18n("Random Layout", nullptr));
        getNewButton->setText(tr2i18n("Download New Layouts\342\200\246", nullptr));
        groupBox_2->setTitle(tr2i18n("Preview", nullptr));
        groupBox->setTitle(tr2i18n("Layout Details", nullptr));
        labelAuthor->setText(tr2i18n("Author:", nullptr));
        labelContact->setText(tr2i18n("Contact:", nullptr));
        labelDescription->setText(tr2i18n("Description:", nullptr));
        (void)KMahjonggLayoutSelector;
    } // retranslateUi

};

namespace Ui {
    class KMahjonggLayoutSelector: public Ui_KMahjonggLayoutSelector {};
} // namespace Ui

QT_END_NAMESPACE

#endif // GAMETYPE_H

